@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -22,7 +22,7 @@
 #include "pimcommon_export.h"
 
 namespace PimCommon {
-class PIMCOMMON_EXPORT AutoCorrectionLanguage : public KComboBox
+class PIMCOMMON_EXPORT AutoCorrectionLanguage : public QComboBox
 {
 public:
     explicit AutoCorrectionLanguage(QWidget *parent);
@@ -32,7 +32,7 @@ public:
     * @brief language
     * @return specified language
     */
-    QString language() const;
+    Q_REQUIRED_RESULT QString language() const;
 
     /**
      * @brief setLanguage
