@@ -25,8 +25,8 @@ class ImportKMailAutocorrection : public ImportAbstractAutocorrection
 {
 public:
     explicit ImportKMailAutocorrection(QWidget *parent = nullptr);
-    ~ImportKMailAutocorrection();
-    bool import(const QString &fileName, ImportAbstractAutocorrection::LoadAttribute loadAttribute = All) override;
+    ~ImportKMailAutocorrection() override;
+    Q_REQUIRED_RESULT bool import(const QString &fileName, ImportAbstractAutocorrection::LoadAttribute loadAttribute = All) override;
 };
 }
 
