@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -22,8 +22,7 @@
 
 #include <PimCommon/SpellCheckLineEdit>
 
-namespace PimCommon
-{
+namespace PimCommon {
 class AutoCorrection;
 class LineEditWithAutoCorrectionPrivate;
 class PIMCOMMON_EXPORT LineEditWithAutoCorrection : public PimCommon::SpellCheckLineEdit
@@ -31,9 +30,9 @@ class PIMCOMMON_EXPORT LineEditWithAutoCorrection : public PimCommon::SpellCheck
     Q_OBJECT
 public:
     explicit LineEditWithAutoCorrection(QWidget *parent, const QString &configFile);
-    ~LineEditWithAutoCorrection();
+    ~LineEditWithAutoCorrection() override;
 
-    PimCommon::AutoCorrection *autocorrection() const;
+    Q_REQUIRED_RESULT PimCommon::AutoCorrection *autocorrection() const;
 
     void setAutocorrection(PimCommon::AutoCorrection *autocorrect);
     void setAutocorrectionLanguage(const QString &language);
