@@ -29,9 +29,9 @@ class PIMCOMMON_EXPORT RichTextEditWithAutoCorrection : public KPIMTextEdit::Ric
     Q_OBJECT
 public:
     explicit RichTextEditWithAutoCorrection(QWidget *parent = nullptr);
-    ~RichTextEditWithAutoCorrection();
+    ~RichTextEditWithAutoCorrection() override;
 
-    PimCommon::AutoCorrection *autocorrection() const;
+    Q_REQUIRED_RESULT PimCommon::AutoCorrection *autocorrection() const;
 
     void setAutocorrection(PimCommon::AutoCorrection *autocorrect);
 
