@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -60,7 +60,7 @@ void IncidencesForWidgetTest::shouldEmitSignalWhenIndexChanged()
 {
     PimCommon::IncidencesForWidget contentType;
     contentType.show();
-    QTest::qWaitForWindowExposed(&contentType);
+    QVERIFY(QTest::qWaitForWindowExposed(&contentType));
     QSignalSpy spy(&contentType, SIGNAL(currentIndexChanged(int)));
     contentType.setCurrentIndex(1);
     QCOMPARE(spy.at(0).count(), 1);
